<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'アンドラ ペセタ',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'アラブ首長国連邦ディルハム',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'アフガニスタン アフガニー (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'アフガニスタン アフガニー',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'アルバニア レク (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'アルバニア レク',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'アルメニア ドラム',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'オランダ領アンティル ギルダー',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'アンゴラ クワンザ',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'アンゴラ クワンザ (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'アンゴラ 新クワンザ (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'アンゴラ 旧クワンザ (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'アルゼンチン アゥストラール',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'アルゼンチン・ペソ・レイ（1970–1983）',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'アルゼンチン・ペソ（1881–1970）',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'アルゼンチン ペソ (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'アルゼンチン ペソ',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'オーストリア シリング',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'オーストラリア ドル',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'アルバ フロリン',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'アゼルバイジャン マナト (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'アゼルバイジャン マナト',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'ボスニア・ヘルツェゴビナ ディナール (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'ボスニア・ヘルツェゴビナ 兌換マルク (BAM)',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'ボスニア・ヘルツェゴビナ 新ディナール（1994–1997）',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'バルバドス ドル',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'バングラデシュ タカ',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'ベルギー フラン (BEC)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'ベルギー フラン',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'ベルギー フラン (BEL)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'ブルガリア レフ',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'ブルガリア社会主義 レフ',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'ブルガリア 新レフ',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'ブルガリア レフ（1879–1952）',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'バーレーン ディナール',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'ブルンジ フラン',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'バミューダ ドル',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'ブルネイ ドル',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'ボリビア ボリビアーノ',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'ボリビア ボリビアーノ (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'ボリビア ペソ',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'ボリビア (Mvdol)',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'ブラジル 新クルゼイロ (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'ブラジル クルザード (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'ブラジル クルゼイロ (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'ブラジル レアル',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'ブラジル 新クルザード (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'ブラジル クルゼイロ (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'ブラジル クルゼイロ（1942–1967）',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'バハマ ドル',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ブータン ニュルタム',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'ビルマ チャット',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'ボツワナ プラ',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'ベラルーシ 新ルーブル (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'ベラルーシ ルーブル',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'ベラルーシ ルーブル (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'ベリーズ ドル',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'カナダ ドル',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'コンゴ フラン',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'ユーロ (WIR)',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'スイス フラン',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'フラン (WIR)',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'チリ エスクード',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'チリ ウニダ・デ・フォメント (UF)',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'チリ ペソ',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => '中国人民元(オフショア)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => '中国人民銀行ドル',
        ],
        'CNY' => [
            0 => '元',
            1 => '中国人民元',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'コロンビア ペソ',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'コロンビア レアル （UVR)',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'コスタリカ コロン',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'セルビア ディナール (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'チェコスロバキア コルナ',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'キューバ 兌換ペソ',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'キューバ ペソ',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'カーボベルデ エスクード',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'キプロス ポンド',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'チェコ コルナ',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => '東ドイツ マルク',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'ドイツ マルク',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'ジブチ フラン',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'デンマーク クローネ',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'ドミニカ ペソ',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'アルジェリア ディナール',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'エクアドル スクレ',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'エクアドル (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'エストニア クルーン',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'エジプト ポンド',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'エリトリア ナクファ',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'スペインペセタ（勘定A）',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'スペイン 兌換ペセタ',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'スペイン ペセタ',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'エチオピア ブル',
        ],
        'EUR' => [
            0 => '€',
            1 => 'ユーロ',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'フィンランド マルカ',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'フィジー ドル',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'フォークランド（マルビナス）諸島 ポンド',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'フランス フラン',
        ],
        'GBP' => [
            0 => '£',
            1 => '英国ポンド',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'ジョージア クーポン ラリ',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'ジョージア ラリ',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ガーナ セディ (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ガーナ セディ',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'ジブラルタル ポンド',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'ガンビア ダラシ',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'ギニア フラン',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'ギニア シリー',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => '赤道ギニア エクウェレ',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'ギリシャ ドラクマ',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'グアテマラ ケツァル',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'ポルトガル領ギニア エスクード',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'ギニアビサウ ペソ',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'ガイアナ ドル',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => '香港ドル',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'ホンジュラス レンピラ',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'クロアチア ディナール',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'クロアチア クーナ',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'ハイチ グールド',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ハンガリー フォリント',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'インドネシア ルピア',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'アイリッシュ ポンド',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'イスラエル ポンド',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'イスラエル シェケル (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'イスラエル新シェケル',
        ],
        'INR' => [
            0 => '₹',
            1 => 'インド ルピー',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'イラク ディナール',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'イラン リアル',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'アイスランド クローナ (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'アイスランド クローナ',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'イタリア リラ',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'ジャマイカ ドル',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'ヨルダン ディナール',
        ],
        'JPY' => [
            0 => '￥',
            1 => '日本円',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'ケニア シリング',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'キルギス ソム',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'カンボジア リエル',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'コモロ フラン',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => '北朝鮮ウォン',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => '韓国 ファン（1953–1962）',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => '韓国 ウォン（1945–1953）',
        ],
        'KRW' => [
            0 => '₩',
            1 => '韓国ウォン',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'クウェート ディナール',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'ケイマン諸島 ドル',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'カザフスタン テンゲ',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'ラオス キープ',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'レバノン ポンド',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'スリランカ ルピー',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'リベリア ドル',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'レソト ロティ',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'リトアニア リタス',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'リトアニア タロナ',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'ルクセンブルク 兌換フラン',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'ルクセンブルグ フラン',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'ルクセンブルク 金融フラン',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'ラトビア ラッツ',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'ラトビア ルーブル',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'リビア ディナール',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'モロッコ ディルハム',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'モロッコ フラン',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'モネガスク フラン',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'モルドバ クーポン',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'モルドバ レイ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'マダガスカル アリアリ',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'マラガシ フラン',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'マケドニア デナル',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'マケドニア ディナール（1992–1993）',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'マリ フラン',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'ミャンマー チャット',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'モンゴル トグログ',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'マカオ パタカ',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'モーリタニア ウギア (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'モーリタニア ウギア',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'マルタ リラ',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'マルタ ポンド',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'モーリシャス ルピー',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'モルディブ諸島 ルピー',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'モルディブ ルフィア',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'マラウィ クワチャ',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'メキシコ ペソ',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'メキシコ ペソ (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'メキシコ (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'マレーシア リンギット',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'モザンピーク エスクード',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'モザンビーク メティカル (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'モザンビーク メティカル',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'ナミビア ドル',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'ナイジェリア ナイラ',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'ニカラグア コルドバ (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'ニカラグア コルドバ オロ',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'オランダ ギルダー',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'ノルウェー クローネ',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'ネパール ルピー',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'ニュージーランド ドル',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'オマーン リアル',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'パナマ バルボア',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'ペルー インティ',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'ペルー ソル',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'ペルー ソル (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'パプアニューギニア キナ',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'フィリピン ペソ',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'パキスタン ルピー',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'ポーランド ズウォティ',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'ポーランド ズウォティ (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'ポルトガル エスクード',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'パラグアイ グアラニ',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'カタール リアル',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'ローデシア ドル',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'ルーマニア レイ (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'ルーマニア レイ',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'ディナール (セルビア)',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'ロシア ルーブル',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'ロシア ルーブル (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'ルワンダ フラン',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'サウジ リヤル',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'ソロモン諸島 ドル',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'セーシェル ルピー',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'スーダン ディナール (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'スーダン ポンド',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'スーダン ポンド (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'スウェーデン クローナ',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'シンガポール ドル',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'セントヘレナ ポンド',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'スロベニア トラール',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'スロバキア コルナ',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'シエラレオネ レオン',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'ソマリア シリング',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'スリナム ドル',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'スリナム ギルダー',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => '南スーダン ポンド',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'サントメ・プリンシペ ドブラ (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'サントメ・プリンシペ ドブラ',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'ソ連 ルーブル',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'エルサルバドル コロン',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'シリア ポンド',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'スワジランド リランゲニ',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'タイ バーツ',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'タジキスタン ルーブル',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'タジキスタン ソモニ',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'トルクメニスタン マナト (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'トルクメニスタン マナト',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'チュニジア ディナール',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'トンガ パ・アンガ',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'ティモール エスクード',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'トルコ リラ (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'トルコリラ',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'トリニダード・トバゴ ドル',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => '新台湾ドル',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'タンザニア シリング',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ウクライナ グリブナ',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ウクライナ カルボバネツ',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ウガンダ シリング (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ウガンダ シリング',
        ],
        'USD' => [
            0 => '$',
            1 => '米ドル',
        ],
        'USN' => [
            0 => 'USN',
            1 => '米ドル (翌日)',
        ],
        'USS' => [
            0 => 'USS',
            1 => '米ドル (当日)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'ウルグアイ ペソエン',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'ウルグアイ ペソ (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'ウルグアイ ペソ',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'ウズベキスタン スム',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'ベネズエラ ボリバル (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'ベネズエラ ボリバル (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'ベネズエラ ボリバル',
        ],
        'VND' => [
            0 => '₫',
            1 => 'ベトナム ドン',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'ベトナム ドン（1978–1985）',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'バヌアツ バツ',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'サモア タラ',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => '中央アフリカ CFA フラン',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => '東カリブ ドル',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ヨーロッパ通貨単位',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'フランス金フラン',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'フランス フラン (UIC)',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => '西アフリカ CFA フラン',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP フラン',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET基金',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'イエメン ディナール',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'イエメン リアル',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'ユーゴスラビア ハード・ディナール (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'ユーゴスラビア ノビ・ディナール (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'ユーゴスラビア 兌換ディナール (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'ユーゴスラビア 改革ディナール（1992–1993）',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => '南アフリカ ランド (ZAL)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => '南アフリカ ランド',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'ザンビア クワチャ (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'ザンビア クワチャ',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'ザイール 新ザイール (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'ザイール ザイール (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'ジンバブエ ドル (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'ジンバブエ ドル (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'シンバブエ ドル（2008）',
        ],
    ],
];
